Run tests
=========

To run pythoncapi-compat tests, type::

    python3 runtests.py

To only test the current Python version, use the ``-c`` or the ``--current``
option::

    python3 runtests.py --current

Verbose mode (``-v``, ``--verbose``)::

    python3 runtests.py --verbose

See tests in the ``tests/`` subdirectory.
